window.Gleam.initSearch([{"doc":"iv","title":"iv","content":"# iv\n\n[![Package Version](https://img.shields.io/hexpm/v/iv)](https://hex.pm/packages/iv)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/iv/)\n\n`iv` is a fast, general-purpose, persistent array structure for Gleam.\n\nYou can use it like you would use an array in other programming languages and\nexpect comparable or better runtime characteristics. It offers\n_O(log n)_ or effectively constant runtime on all main operations, including\n`concat` and `split`, making it an excellent choice when parallelising workloads.\n\n\n### Benchmarks\n\n`iv` does not try to be the fastest at anything, but offer consistent, high\nperformance across all types of workloads.\n\nYou can find benchmarks [here](./benchmarks.html).\n\n### Installation\n\n```sh\ngleam add iv@1\n```\n\n### Example: Bubble-Sort\n\n```gleam\nimport iv\nimport gleam/int\n\n// bubble sort, in my gleam?\npub fn main() {\n  // make an array of 10 random integers\n  let array = iv.initialise(10, fn(_) { int.random(100) })\n  let sorted = bubble_sort(array)\n\n  use item &lt;- iv.each(sorted)\n\n  io.println(int.to_string(item))\n}\n\nfn bubble_sort(array) {\n  bubble_sort_loop(array, 1, iv.length(array))\n}\n\nfn bubble_sort_loop(array, index, max_index) {\n  case iv.get(array, index - 1), iv.get(array, index) {\n    // found 2 elements in the wrong order, swap them, then continue\n    Ok(prev), Ok(curr) if prev &gt; curr -&gt; {\n      let array =\n        array\n        |&gt; iv.try_set(index, prev)\n        |&gt; iv.try_set(index - 1, curr)\n      bubble_sort_loop(array, index + 1, max_index)\n    }\n\n    // found 2 elements in the correct order, we can skip them!\n    Ok(_), Ok(_) -&gt; bubble_sort_loop(array, index + 1, max_index)\n\n    // reached the end, decrease max_index then try again!\n    _, _ if max_index &gt; 2 -&gt; bubble_sort_loop(array, 1, max_index - 1)\n    // reached the end and no more elements to swap, we are done.\n    _, _ -&gt; array\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/iv&gt;.\n\n### Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam run -m benchmark # Run the benchmarks\n```\n\n### Implementation\n\n`iv` is based on the _RRB-Vector_, an advanced immutable data structure based\non Closures persistent vectors developed by Bagwell and Rompf. If you&#39;re\ninterested in that sort of thing, I highly recommend also checking out L&#39;oranges\nmasters thesis, which is a very rigorous presentation of the algorithms and\nmathematics behind them. The blog post by Horne-Khan implements the main ideas,\nbut is easier to digest without a strong computer science background.\n\n`iv` improves on the data structure as presented by offering fast appends,\nprepends and inserts for arbitrary numbers of elements and improving general\nnode reconstruction time.\n\n- L’orange, J. N. (2014). Improving RRB-Tree Performance through Transience \\\n  Available: &lt;https://hypirion.com/thesis.pdf&gt;\n- Stucki, N., Rompf, T., Ureche, V., &amp; Bagwell, P. (2015). RRB Vector: a practical general purpose immutable sequence. In Proceedings of the 20th ACM SIGPLAN International Conference on Functional Programming (pp. 342-354). \\\n  Available: &lt;https://www.cs.purdue.edu/homes/rompf/papers/stucki-icfp15.pdf&gt;\n- Bagwell, P., Rompf, T. (2011). RRB-Trees: efficient immutable vectors. \\\n  Available: &lt;http://infoscience.epfl.ch/record/169879/files/RMTrees.pdf&gt;\n- Horne-Khan, P. (2024). Relaxed Radix Balanced Trees. \\\n  Available: &lt;https://peter.horne-khan.com/relaxed-radix-balanced-trees/&gt;\n- konsumlamm (2021). rrb-vector: Efficient RRB-Vectors. \\\n  Available: &lt;https://github.com/konsumlamm/rrb-vector&gt;\n- Hansen, R. H. (2017). Elm array exploration. \\\n  Available: &lt;https://github.com/robinheghan/elm-array-exploration&gt;\n\n\n","url":"index.html"},{"doc":"iv","title":"iv","content":"&lt;style&gt;\n@import &quot;https://unpkg.com/charts.css/dist/charts.min.css&quot;;\n\n.benchmark {\n  margin-top: 1em;\n\n  .charts-css {\n    --primary-axis-color: var(--bg-mono-1);\n    --data-axes-color: var(--bg-mono-1);\n    --color-2: var(--color-6);\n\n    &amp;.legend {\n      margin-top: 1em;\n      font-size: 0.75em;\n      padding: 0.5rem;\n      --legend-border-color: var(--bg-mono-1);\n    }\n\n    caption {\n      margin-bottom: 0.5em;\n    }\n  }\n\n  table {\n    min-width: 100%;\n  }\n\n  table:not(.charts-css) + .legend {\n    display: none;\n  }\n\n  button {\n    border: 1px solid var(--bg-mono-1);\n    border-radius: 2px;\n    font-size: 0.75em;\n    color: inherit;\n    float: right;\n    padding: 0.5em 1em;\n\n    &amp;:hover {\n      background: var(--bg-mono-1);\n    }\n  }\n}\n&lt;/style&gt;\n&lt;script&gt;\n(cb =&gt; document.readyState !== &#39;loading&#39; ? cb() : document.addEventListener(&#39;DOMContentLoaded&#39;, cb, { once: true }))(() =&gt; {\n  document.querySelectorAll(&#39;.benchmark button&#39;).forEach(btn =&gt; btn.addEventListener(&#39;click&#39;, () =&gt; {\n    btn.parentElement.querySelector(&#39;table&#39;).classList.toggle(&#39;charts-css&#39;)\n  }))\n})\n&lt;/script&gt;\n\n# Benchmarks\n\nBenchmarks were run using Gleam 1.8, Erlang/OTP-27.1.2 on Windows 11 and an AMD Ryzen 7 PRO 5850U.\nThe numbers are instructions per second (IPS). Higher is better.\n\nThe goal of `iv` is to provide consistent, reliable performance across all kinds of workloads.\n\n&lt;div class=&quot;benchmark&quot;&gt;\n  &lt;button&gt;chart / data&lt;/button&gt;\n  &lt;table class=&quot;charts-css line multiple show-primary-axis show-data-axes show-heading show-labels show-data-on-hover&quot; style=&quot;--max: calc(log(3798293, 10))&quot;&gt;\n    &lt;caption&gt;create from list&lt;/caption&gt;\n    &lt;thead&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;col&quot;&gt;N&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;ivy&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;gary&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;glearray&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;list&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;dict&lt;/th&gt;\n      &lt;/tr&gt;\n    &lt;/thead&gt;\n    &lt;tbody&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(log(1022185, 10) / var(--max)); --end: calc(log(171572, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 1.0M&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(781399, 10) / var(--max)); --end: calc(log(73127, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 781k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(2905939, 10) / var(--max)); --end: calc(log(112268, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 2.9M&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(3798293, 10) / var(--max)); --end: calc(log(808000, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 3.8M&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(1721946, 10) / var(--max)); --end: calc(log(96840, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 1.7M&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(log(171572, 10) / var(--max)); --end: calc(log(17835, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 172k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(73127, 10) / var(--max)); --end: calc(log(5945, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 73.1k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(112268, 10) / var(--max)); --end: calc(log(1308, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 112k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(808000, 10) / var(--max)); --end: calc(log(91693, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 808k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(96840, 10) / var(--max)); --end: calc(log(9725, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 96.8k&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;1000&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(log(17835, 10) / var(--max)); --end: calc(log(2041, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 17.8k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(5945, 10) / var(--max)); --end: calc(log(498, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 5945&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(1308, 10) / var(--max)); --end: calc(log(13, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 1308&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(91693, 10) / var(--max)); --end: calc(log(9274, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 91.7k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(9725, 10) / var(--max)); --end: calc(log(607, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 9725&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(log(2041, 10) / var(--max)); --end: calc(log(203, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 2041&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(498, 10) / var(--max)); --end: calc(log(41, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 498&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(13, 10) / var(--max)); --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 13&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(9274, 10) / var(--max)); --end: calc(log(925, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 9274&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(607, 10) / var(--max)); --end: calc(log(32, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 607&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(log(203, 10) / var(--max)); --end: calc(log(14.6, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 203&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(41, 10) / var(--max)); --end: calc(log(4, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 41&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: 0; --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: n/a&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(925, 10) / var(--max)); --end: calc(log(93, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 925&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(32, 10) / var(--max)); --end: calc(log(2, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 32&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n    &lt;/tbody&gt;\n  &lt;/table&gt;\n  &lt;ul class=&quot;charts-css legend legend-inline legend-line&quot;&gt;\n    &lt;li&gt;iv&lt;/li&gt;\n    &lt;li&gt;gary&lt;/li&gt;\n    &lt;li&gt;glearray&lt;/li&gt;\n    &lt;li&gt;list&lt;/li&gt;\n    &lt;li&gt;dict&lt;/li&gt;\n  &lt;/ul&gt;\n\n  &lt;p&gt;\n    &lt;i&gt;For lists, the provided numbers are the performance of the baseline &lt;code&gt;list.range&lt;/code&gt; call.&lt;/i&gt;\n  &lt;/p&gt;\n&lt;/div&gt;\n\n&lt;div class=&quot;benchmark&quot;&gt;\n  &lt;button&gt;chart / data&lt;/button&gt;\n  &lt;table class=&quot;charts-css line multiple show-primary-axis show-data-axes show-heading show-labels show-data-on-hover&quot; style=&quot;--max: 1051&quot;&gt;\n    &lt;caption&gt;insert 1k elements at the center&lt;/caption&gt;\n    &lt;thead&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;col&quot;&gt;N&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;ivy&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;gary&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;glearray&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;list&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;dict&lt;/th&gt;\n      &lt;/tr&gt;\n    &lt;/thead&gt;\n    &lt;tbody&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(206 / var(--max)); --end: calc(253 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 206&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(9.44 / var(--max)); --end: calc(7.94 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 9.44&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(1051 / var(--max)); --end: calc(896 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 1051&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(221 / var(--max)); --end: calc(189 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 221&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(13.5 / var(--max)); --end: calc(11.3 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 13.5&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(253 / var(--max)); --end: calc(211 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 253&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(7.94 / var(--max)); --end: calc(2.72 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 7.94&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(896 / var(--max)); --end: calc(367 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 896&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(189 / var(--max)); --end: calc(72.6 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 189&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(11.3 / var(--max)); --end: calc(3.83 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 11.3&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;1000&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(211 / var(--max)); --end: calc(148 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 211&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(2.72 / var(--max)); --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 2.72&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(367 / var(--max)); --end: calc(53.2 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 367&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(72.6 / var(--max)); --end: calc(10.2 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 72.6&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(3.83 / var(--max)); --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 3.83&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(148 / var(--max)); --end: calc(119 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 148&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: 0; --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: n/a&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(53.2 / var(--max)); --end: calc(5.52 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 53.2&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(10.2 / var(--max)); --end: calc(1.1 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 10.2&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: 0; --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: n/a&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(119 / var(--max)); --end: calc(89.6 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 119&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: 0; --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: n/a&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(5.52 / var(--max)); --end: calc(0.55 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 5.52&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(1.1 / var(--max)); --end: calc(0.11 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 1.10&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: 0; --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: n/a&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n    &lt;/tbody&gt;\n  &lt;/table&gt;\n  &lt;ul class=&quot;charts-css legend legend-inline legend-line&quot;&gt;\n    &lt;li&gt;iv&lt;/li&gt;\n    &lt;li&gt;gary&lt;/li&gt;\n    &lt;li&gt;glearray&lt;/li&gt;\n    &lt;li&gt;list&lt;/li&gt;\n    &lt;li&gt;dict&lt;/li&gt;\n  &lt;/ul&gt;\n\n  &lt;p&gt;\n    &lt;i&gt;Note: Only &lt;code&gt;iv&lt;/code&gt; and &lt;code&gt;glearray&lt;/code&gt; provide native insert algorithms. Others where implemented by copying the existing array, with the new item added.&lt;/i&gt;\n  &lt;/p&gt;\n&lt;/div&gt;\n\n&lt;div class=&quot;benchmark&quot;&gt;\n  &lt;button&gt;chart / data&lt;/button&gt;\n  &lt;table class=&quot;charts-css line multiple show-primary-axis show-data-axes show-heading show-labels show-data-on-hover&quot; style=&quot;--max: 7810&quot;&gt;\n    &lt;caption&gt;append 1k elements&lt;/caption&gt;\n    &lt;thead&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;col&quot;&gt;N&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;ivy&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;gary&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;glearray&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;list&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;dict&lt;/th&gt;\n      &lt;/tr&gt;\n    &lt;/thead&gt;\n    &lt;tbody&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(3281 / var(--max)); --end: calc(4166 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 3281&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(5406 / var(--max)); --end: calc(5816 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 5406&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(1294 / var(--max)); --end: calc(1102 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 1294&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(534 / var(--max)); --end: calc(458 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 534&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(7810 / var(--max)); --end: calc(7151 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 7810&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(4166 / var(--max)); --end: calc(3901 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 4166&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(5816 / var(--max)); --end: calc(4987 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 5816&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(1102 / var(--max)); --end: calc(446 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 1102&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(458 / var(--max)); --end: calc(185 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 458&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(7151 / var(--max)); --end: calc(6839 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 7151&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;1000&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(3901 / var(--max)); --end: calc(3040 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 3901&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(4987 / var(--max)); --end: calc(4186 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 4987&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(446 / var(--max)); --end: calc(64.2 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 446&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(185 / var(--max)); --end: calc(26.3 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 185&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(6839 / var(--max)); --end: calc(5376 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 6839&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(3040 / var(--max)); --end: calc(2505 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 3040&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(4184 / var(--max)); --end: calc(3545 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 4184&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(64.2 / var(--max)); --end: calc(5.85 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 64.2&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(26.3 / var(--max)); --end: calc(2.4 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 26.3&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(5376 / var(--max)); --end: calc(3859 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 5376&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(2505 / var(--max)); --end: calc(2465 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 2505&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(3545 / var(--max)); --end: calc(2700 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 3545&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(5.85 / var(--max)); --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 5.85&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(2.4 / var(--max)); --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 2.40&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(3859 / var(--max)); --end: calc(2800 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 3859&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n    &lt;/tbody&gt;\n  &lt;/table&gt;\n  &lt;ul class=&quot;charts-css legend legend-inline legend-line&quot;&gt;\n    &lt;li&gt;iv&lt;/li&gt;\n    &lt;li&gt;gary&lt;/li&gt;\n    &lt;li&gt;glearray&lt;/li&gt;\n    &lt;li&gt;list&lt;/li&gt;\n    &lt;li&gt;dict&lt;/li&gt;\n  &lt;/ul&gt;\n&lt;/div&gt;\n\n&lt;div class=&quot;benchmark&quot;&gt;\n  &lt;button&gt;chart / data&lt;/button&gt;\n  &lt;table class=&quot;charts-css line multiple show-primary-axis show-data-axes show-heading show-labels show-data-on-hover&quot; style=&quot;--max: 7780&quot;&gt;\n    &lt;caption&gt;prepend 1k elements&lt;/caption&gt;\n    &lt;thead&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;col&quot;&gt;N&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;ivy&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;gary&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;glearray&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;dict&lt;/th&gt;\n      &lt;/tr&gt;\n    &lt;/thead&gt;\n    &lt;tbody&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(1856 / var(--max)); --end: calc(1911 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 1856&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(11.5 / var(--max)); --end: calc(9.73 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 11.5&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(1269 / var(--max)); --end: calc(1080 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 1269&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(7780 / var(--max)); --end: calc(7380 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 7780&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(1911 / var(--max)); --end: calc(1759 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 1911&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(9.73 / var(--max)); --end: calc(3.34 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 9.73&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(1080 / var(--max)); --end: calc(448 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 1080&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(7380 / var(--max)); --end: calc(6864 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 7380&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;1000&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(1759 / var(--max)); --end: calc(1559 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 1659&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(3.34 / var(--max)); --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 3.34&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(448 / var(--max)); --end: calc(64.4 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 448&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(6864 / var(--max)); --end: calc(5383 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 6864&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(1559 / var(--max)); --end: calc(1371 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 1559&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: 0; --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: n/a&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(64.4 / var(--max)); --end: calc(5.76 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 64.4&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(5383 / var(--max)); --end: calc(3870 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 5383&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(1371 / var(--max)); --end: calc(1245 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 1371&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: 0; --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: n/a&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(5.76 / var(--max)); --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 5.76&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(3870 / var(--max)); --end: calc(2800 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 3870&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n    &lt;/tbody&gt;\n  &lt;/table&gt;\n  &lt;ul class=&quot;charts-css legend legend-inline legend-line&quot;&gt;\n    &lt;li&gt;iv&lt;/li&gt;\n    &lt;li&gt;gary&lt;/li&gt;\n    &lt;li&gt;glearray&lt;/li&gt;\n    &lt;li&gt;dict&lt;/li&gt;\n  &lt;/ul&gt;\n\n  &lt;p&gt;\n    &lt;i&gt;Note: lists where excluded to make the chart more readable. Lists provide constant prepends regardless of list size. I was able to achieve 44.2k IPS using lists in this benchmark.&lt;/i&gt;\n&lt;/div&gt;\n\n\n&lt;div class=&quot;benchmark&quot;&gt;\n  &lt;button&gt;chart / data&lt;/button&gt;\n  &lt;table class=&quot;charts-css line multiple show-primary-axis show-data-axes show-heading show-labels show-data-on-hover&quot; style=&quot;--max: 13938&quot;&gt;\n    &lt;caption&gt;set 1k elements at the center&lt;/caption&gt;\n    &lt;thead&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;col&quot;&gt;N&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;ivy&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;gary&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;glearray&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;list&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;dict&lt;/th&gt;\n      &lt;/tr&gt;\n    &lt;/thead&gt;\n    &lt;tbody&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(11057 / var(--max)); --end: calc(7293 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 11057&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(8818 / var(--max)); --end: calc(6374 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 8818&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(13938 / var(--max)); --end: calc(4769 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 13938&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(7332 / var(--max)); --end: calc(1072 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 7332&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(13394 / var(--max)); --end: calc(8574 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 13394&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(7293 / var(--max)); --end: calc(5564 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 7293&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(6374 / var(--max)); --end: calc(4696 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 6374&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(4769 / var(--max)); --end: calc(569 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 4769&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(1072 / var(--max)); --end: calc(101.8 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 1072&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(8574 / var(--max)); --end: calc(6257 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 8574&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;1000&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(5564 / var(--max)); --end: calc(4402 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 5564&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(4696 / var(--max)); --end: calc(4183 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 4696&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(569 / var(--max)); --end: calc(58 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 569&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(102 / var(--max)); --end: calc(9.24 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 102&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(6257 / var(--max)); --end: calc(5294 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 6257&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(4402 / var(--max)); --end: calc(3626 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 4402&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(4183 / var(--max)); --end: calc(3612 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 4183&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(58 / var(--max)); --end: calc(5.72 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 58.0&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(9.24 / var(--max)); --end: calc(0.88 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 9.24&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(5294 / var(--max)); --end: calc(4642 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 5294&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(3626 / var(--max)); --end: calc(3361 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 3626&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(3612 / var(--max)); --end: calc(3100 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 3612&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(5.72 / var(--max)); --end: calc(0.57 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 5.72&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(0.88 / var(--max)); --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 0.88&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(4642 / var(--max)); --end: calc(3900 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 4642&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n    &lt;/tbody&gt;\n  &lt;/table&gt;\n  &lt;ul class=&quot;charts-css legend legend-inline legend-line&quot;&gt;\n    &lt;li&gt;iv&lt;/li&gt;\n    &lt;li&gt;gary&lt;/li&gt;\n    &lt;li&gt;glearray&lt;/li&gt;\n    &lt;li&gt;list&lt;/li&gt;\n    &lt;li&gt;dict&lt;/li&gt;\n  &lt;/ul&gt;\n&lt;/div&gt;\n\n\n\n&lt;div class=&quot;benchmark&quot;&gt;\n  &lt;button&gt;chart / data&lt;/button&gt;\n  &lt;table class=&quot;charts-css line multiple show-primary-axis show-data-axes show-heading show-labels show-data-on-hover&quot; style=&quot;--max: 44048&quot;&gt;\n    &lt;caption&gt;get 1k elements at the center&lt;/caption&gt;\n    &lt;thead&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;col&quot;&gt;N&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;ivy&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;gary&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;glearray&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;list&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;dict&lt;/th&gt;\n      &lt;/tr&gt;\n    &lt;/thead&gt;\n    &lt;tbody&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(44048 / var(--max)); --end: calc(26950 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 44048&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(16232 / var(--max)); --end: calc(13670 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 16232&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(39230 / var(--max)); --end: calc(39732 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 39230&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(34863 / var(--max)); --end: calc(8783 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 34863&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(26966 / var(--max)); --end: calc(21410 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 26966&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(26950 / var(--max)); --end: calc(23603 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 26950&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(13670 / var(--max)); --end: calc(10649 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 13670&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(39732 / var(--max)); --end: calc(39726 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 39732&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(8783 / var(--max)); --end: calc(942 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 8783&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(21410 / var(--max)); --end: calc(18506 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 21410&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;1000&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(23603 / var(--max)); --end: calc(19716 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 23603&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(10649 / var(--max)); --end: calc(10650 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 10649&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(39726 / var(--max)); --end: calc(39850 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 39726&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(942 / var(--max)); --end: calc(98.8 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 942&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(18506 / var(--max)); --end: calc(17601 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 18506&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(19716 / var(--max)); --end: calc(16928 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 19716&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(10650 / var(--max)); --end: calc(9532 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 10650&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(39850 / var(--max)); --end: calc(38818 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 39850&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(98.8 / var(--max)); --end: calc(10.1 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 98.8&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(17601 / var(--max)); --end: calc(19670 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 17601&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(16928 / var(--max)); --end: calc(16968 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 16928&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(9532 / var(--max)); --end: calc(9300 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 9532&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(38817 / var(--max)); --end: calc(38000 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 38817&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(10.1 / var(--max)); --end: calc(1 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 10.1&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(19670 / var(--max)); --end: calc(17000 / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 19670&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n    &lt;/tbody&gt;\n  &lt;/table&gt;\n  &lt;ul class=&quot;charts-css legend legend-inline legend-line&quot;&gt;\n    &lt;li&gt;iv&lt;/li&gt;\n    &lt;li&gt;gary&lt;/li&gt;\n    &lt;li&gt;glearray&lt;/li&gt;\n    &lt;li&gt;list&lt;/li&gt;\n    &lt;li&gt;dict&lt;/li&gt;\n  &lt;/ul&gt;\n&lt;/div&gt;\n\n\n&lt;div class=&quot;benchmark&quot;&gt;\n  &lt;button&gt;chart / data&lt;/button&gt;\n  &lt;table class=&quot;charts-css line multiple show-primary-axis show-data-axes show-heading show-labels show-data-on-hover&quot; style=&quot;--max: calc(log(4991216, 10))&quot;&gt;\n    &lt;caption&gt;iterate (map)&lt;/caption&gt;\n    &lt;thead&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;col&quot;&gt;N&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;ivy&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;gary&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;glearray&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;list&lt;/th&gt;\n        &lt;th scope=&quot;col&quot;&gt;dict&lt;/th&gt;\n      &lt;/tr&gt;\n    &lt;/thead&gt;\n    &lt;tbody&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(log(4991216, 10) / var(--max)); --end: calc(log(1187282, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 5.0M&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(1996555, 10) / var(--max)); --end: calc(log(285534, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 2.0M&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(1248261, 10) / var(--max)); --end: calc(log(76603, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 1.3M&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(2801604, 10) / var(--max)); --end: calc(log(570708, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 2.8M&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(1518647, 10) / var(--max)); --end: calc(log(102477, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 1.5M&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(log(1187282, 10) / var(--max)); --end: calc(log(152916, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 1.2M&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(285534, 10) / var(--max)); --end: calc(log(28361, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 286k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(76603, 10) / var(--max)); --end: calc(log(1087, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 76.6k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(570708, 10) / var(--max)); --end: calc(log(61512, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 571k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(102477, 10) / var(--max)); --end: calc(log(8194, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 102k&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;1000&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(log(152916, 10) / var(--max)); --end: calc(log(15991, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 153k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(28361, 10) / var(--max)); --end: calc(log(3131, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 28.4k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(1087, 10) / var(--max)); --end: calc(log(11.4, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 1087&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(61512, 10) / var(--max)); --end: calc(log(6391, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 61.5k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(8194, 10) / var(--max)); --end: calc(log(674, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 8194&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;10k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(log(15991, 10) / var(--max)); --end: calc(log(1590, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 16k&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(3131, 10) / var(--max)); --end: calc(log(317, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 3131&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(11.4, 10) / var(--max)); --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: 11.4&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(6391, 10) / var(--max)); --end: calc(log(621, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 6391&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(674, 10) / var(--max)); --end: calc(log(56.7, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 674&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n      &lt;tr&gt;\n        &lt;th scope=&quot;row&quot;&gt;100k&lt;/th&gt;\n        &lt;td style=&quot;--start: calc(log(1590, 10) / var(--max)); --end: calc(log(159, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;iv: 1590&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(317, 10) / var(--max)); --end: calc(log(31, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;gary: 317&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: 0; --end: 0&quot;&gt;&lt;span class=&quot;data&quot;&gt;gle: n/a&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(621, 10) / var(--max)); --end: calc(log(62, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;list: 621&lt;/span&gt;&lt;/td&gt;\n        &lt;td style=&quot;--start: calc(log(56.7, 10) / var(--max)); --end: calc(log(7, 10) / var(--max))&quot;&gt;&lt;span class=&quot;data&quot;&gt;dict: 56.7&lt;/span&gt;&lt;/td&gt;\n      &lt;/tr&gt;\n    &lt;/tbody&gt;\n  &lt;/table&gt;\n  &lt;ul class=&quot;charts-css legend legend-inline legend-line&quot;&gt;\n    &lt;li&gt;iv&lt;/li&gt;\n    &lt;li&gt;gary&lt;/li&gt;\n    &lt;li&gt;glearray&lt;/li&gt;\n    &lt;li&gt;list&lt;/li&gt;\n    &lt;li&gt;dict&lt;/li&gt;\n  &lt;/ul&gt;\n&lt;/div&gt;\n","url":"benchmarks.html"},{"doc":"iv","title":"Array","content":"pub opaque type Array(item)\n A fast immutable array.\n\nSynonyms:\niv.Array\niv Array","url":"iv.html#Array"},{"doc":"iv","title":"all","content":"pub fn all(\n  in array: Array(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Check if a fuction returns `True` for every element in the array.\n\n \n all(new(), int.is_even)\n  // --&gt; True\n\n all(from_list([1, 2, 3]), int.is_even)\n // --&gt; False\n\n all(from_list([2, 4, 6]), int.is_even)\n // --&gt; True\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.all\niv all","url":"iv.html#all"},{"doc":"iv","title":"any","content":"pub fn any(\n  in array: Array(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Check if a function returns `True` for at least one of the elements\n in the array.\n\n \n any(new(), int.is_even)\n // --&gt; False\n\n any(from_list([1, 3, 5]), int.is_even)\n // --&gt; False\n\n any(from_list([1, 2, 3]), int.is_even)\n // --&gt; True\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.any\niv any","url":"iv.html#any"},{"doc":"iv","title":"append","content":"pub fn append(to array: Array(a), this item: a) -&gt; Array(a)\n Add an element to the end of an array.\n\n \n from_list([&quot;hello&quot;]) |&gt; append(&quot;joe&quot;)\n // --&gt; from_list([&quot;hello&quot;, &quot;joe&quot;])\n\n from_list([1, 2, 3]) |&gt; append(4) |&gt; append(0)\n // --&gt; from_list([1, 2, 3, 4, 0])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.append\niv append","url":"iv.html#append"},{"doc":"iv","title":"append_list","content":"pub fn append_list(\n  to array: Array(a),\n  these items: List(a),\n) -&gt; Array(a)\n Add all elements in a list to the end of the array.\n\n This more efficient than `append`-ing all elements individually.\n\n This function runs in _O(n)_ time, only depending on the size of the appended list.\n\n \n from_list([1, 2, 3]) |&gt; append_list([4, 0])\n // --&gt; from_list([1, 2, 3, 4, 0])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.append_list\niv append_list","url":"iv.html#append_list"},{"doc":"iv","title":"concat","content":"pub fn concat(\n  left left: Array(a),\n  right right: Array(a),\n) -&gt; Array(a)\n Concatenate two arrays.\n\n This function runs in _O(log n)_ time.\n\n \n concat(from_list([1, 2, 3]), from_list([4, 5, 6]))\n // --&gt; from_list([1, 2, 3, 4, 5, 6])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.concat\niv concat","url":"iv.html#concat"},{"doc":"iv","title":"concat_list","content":"pub fn concat_list(arrays: List(Array(a))) -&gt; Array(a)\n Concatenate many array, joining them up to form a single array.\n\n This function runs in _O(n)_ time, only depending on the number of arrays.\n\n \n concat_list([from_list([1]), new(), from_list([2, 3])])\n // --&gt; from_list([1, 2, 3])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.concat_list\niv concat_list","url":"iv.html#concat_list"},{"doc":"iv","title":"contains","content":"pub fn contains(in array: Array(a), any item: a) -&gt; Bool\n Linearly search through the array to check if it contains an item.\n\n \n contains(in: new(), any: 0)\n // --&gt; False\n\n contains(in: from_list([1, 2, 3]), any: 2)\n // --&gt; True\n\n contains(in: from_list([1, 2, 3]), any: 5)\n // --&gt; False\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.contains\niv contains","url":"iv.html#contains"},{"doc":"iv","title":"delete","content":"pub fn delete(\n  from array: Array(a),\n  at index: Int,\n) -&gt; Result(Array(a), Nil)\n Remove the element at a given index, moving all subsequent elements\n to the left.\n\n This function runs in _O(log n)_ time.\n\n \n from_list([1, 2, 3]) |&gt; delete(at: 1)\n // --&gt; Ok(from_list([1, 3]))\n\n from_list([1, 2, 3]) |&gt; delete(at: 3)\n // --&gt; Error(Nil)\n\n from_list([]) |&gt; delete(at: 0)\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.delete\niv delete","url":"iv.html#delete"},{"doc":"iv","title":"drop_first","content":"pub fn drop_first(from array: Array(a), up_to n: Int) -&gt; Array(a)\n Remove up to `n` elements from the start of the array.\n\n If the array has less than `n` elements an empty array is returned.\n\n This function runs in _O(log n)_ time.\n\n \n drop_first(from_list([1, 2, 3, 4]), up_to: 2)\n // --&gt; from_list([3, 4])\n\n drop_first(from_list([1, 2, 3, 4]), up_to: 5)\n // --&gt; new()\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.drop_first\niv drop_first","url":"iv.html#drop_first"},{"doc":"iv","title":"drop_last","content":"pub fn drop_last(from array: Array(a), up_to n: Int) -&gt; Array(a)\n Remove up to `n` elements from the end of the array.\n\n If the array has less than `n` elements an empty array is returned.\n\n This function runs in _O(log n)_ time.\n\n \n drop_last(from_list([1, 2, 3, 4]), up_to: 2)\n // --&gt; from_list([1, 2])\n\n drop_last(from_list([1, 2, 3, 4]), up_to: 5)\n // --&gt; new()\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.drop_last\niv drop_last","url":"iv.html#drop_last"},{"doc":"iv","title":"each","content":"pub fn each(in array: Array(a), do something: fn(a) -&gt; b) -&gt; Nil\n Loop through the elements from the start to the end, calling a function\n and discarding the result.\n\n Useful for performing some side-effects for every element.\n\n \n use item &lt;- each(from_list([1, 2, 3]))\n io.println(int.to_string(item))\n // 1\n // 2\n // 3\n // --&gt; Nil\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.each\niv each","url":"iv.html#each"},{"doc":"iv","title":"each_right","content":"pub fn each_right(\n  in array: Array(a),\n  do something: fn(a) -&gt; b,\n) -&gt; Nil\n Loop through the elements in reverse order from the end to the start,\n calling a function on each element and discarding the result.\n\n Useful for performing some side-effects for every element.\n\n \n use item &lt;- each(from_list([1, 2, 3]))\n io.println(int.to_string(item))\n // 3\n // 2\n // 1\n // --&gt; Nil\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.each_right\niv each_right","url":"iv.html#each_right"},{"doc":"iv","title":"equal","content":"pub fn equal(a: Array(a), b: Array(a)) -&gt; Bool\n Checks whether or not two arrays are equal. Arrays are considered to be\n equal if they have the same length, and their elements are pairwise equal.\n\n **Important:** Always use this function instead of the `==` operator! \\\n Arrays containing the same elements can have different runtime representations.\n\n \n equal(from_list([1, 2, 3]), range(1, 3))\n // --&gt; True\n\n equal(from_list([1, 2, 3]), from_list([1]))\n // --&gt; False\n\n equal(from_list([1, 2, 3]), from_list([1, 2, 4]))\n // --&gt; False\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.equal\niv equal","url":"iv.html#equal"},{"doc":"iv","title":"filter","content":"pub fn filter(\n  array: Array(a),\n  keeping predicate: fn(a) -&gt; Bool,\n) -&gt; Array(a)\n Build a new array containing only the elements for which the given function\n returns `True`.\n\n \n filter(from_list([1, 2, 3, 4]), int.is_even)\n // --&gt; from_list([2, 4])\n\n filter(from_list([1, 2, 3, 4]), fn(x) { x &gt; 6 })\n // --&gt; new()\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.filter\niv filter","url":"iv.html#filter"},{"doc":"iv","title":"filter_map","content":"pub fn filter_map(\n  array: Array(a),\n  with fun: fn(a) -&gt; Result(b, c),\n) -&gt; Array(b)\n Build a new array containing only the values for which the given function\n returns `Ok(_)`.\n\n \n filter_map(from_list([[], [1], [2, 3]]), list.first)\n // --&gt; from_list([1, 2])\n\n filter_map(from_list([1, 2, 3]), Error)\n // --&gt; new()\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.filter_map\niv filter_map","url":"iv.html#filter_map"},{"doc":"iv","title":"find","content":"pub fn find(\n  in array: Array(a),\n  one_that is_desired: fn(a) -&gt; Bool,\n) -&gt; Result(a, Nil)\n Find the first element from the start  of the array for which the given\n function returns `True`, and return it.\n\n \n find(from_list([1, 2, 3, 4]), fn(x) { x &gt; 2 })\n // --&gt; Ok(3)\n\n find(from_list([1, 2, 3, 4]), fn(x) { x &gt; 4 })\n // --&gt; Error(Nil)\n\n find(new(), fn(_) { True })\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.find\niv find","url":"iv.html#find"},{"doc":"iv","title":"find_index","content":"pub fn find_index(\n  in array: Array(a),\n  one_that is_desired: fn(a) -&gt; Bool,\n) -&gt; Result(Int, Nil)\n Return the index of the first element in the array for which the given\n function returns `True`, or `Error(Nil)` if no such element can be found.\n\n \n find_index(from_list([4, 5, 6, 5]), fn(x) { x &gt; 5 })\n // --&gt; Ok(2)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.find_index\niv find_index","url":"iv.html#find_index"},{"doc":"iv","title":"find_last_index","content":"pub fn find_last_index(\n  in array: Array(a),\n  one_that is_desired: fn(a) -&gt; Bool,\n) -&gt; Result(Int, Nil)\n Return the index of the last element in the array for which the given\n function returns `True`, or `Error(Nil)` if no such element can be found.\n\n \n find_last_index(from_list([4, 5, 6, 7]), fn(x) { x &gt; 5 })\n // --&gt; Ok(3)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.find_last_index\niv find_last_index","url":"iv.html#find_last_index"},{"doc":"iv","title":"find_map","content":"pub fn find_map(\n  in array: Array(a),\n  one_that is_desired: fn(a) -&gt; Result(b, Nil),\n) -&gt; Result(b, Nil)\n Find the first element for which the given function returns `Ok(value)`,\n and return the wrapped value.\n\n \n find_map(from_list([[], [2], [3]]), list.first)\n // --&gt; Ok(2)\n\n find_map(from_list([[], []]), list.first)\n // --&gt; Error(Nil)\n\n find_map(new(), first)\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.find_map\niv find_map","url":"iv.html#find_map"},{"doc":"iv","title":"first","content":"pub fn first(from array: Array(a)) -&gt; Result(a, Nil)\n Get the first element from the start of the array, if there is one.\n\n \n first(new())\n // --&gt; Error(Nil)\n\n first(from_list([1, 2, 3]))\n // --&gt; Ok(1)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.first\niv first","url":"iv.html#first"},{"doc":"iv","title":"flat_map","content":"pub fn flat_map(\n  array: Array(a),\n  with fun: fn(a) -&gt; Array(b),\n) -&gt; Array(b)\n Map every element in the array to a new array, and then flatten them.\n\n \n flat_map(from_list([2, 4, 6]), fn(x) { from_list([x, x + 1]) })\n // --&gt; from_list([2, 3, 4, 5, 6, 7])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.flat_map\niv flat_map","url":"iv.html#flat_map"},{"doc":"iv","title":"flatten","content":"pub fn flatten(arrays: Array(Array(a))) -&gt; Array(a)\n Concatenate many arrays, joining them up to form a single array.\n\n This function runs in _O(n)_ time, only depending on the number of arrays.\n\n \n flatten(from_list([from_list([1]), new(), from_list([2, 3])]))\n // --&gt; from_list([1, 2, 3])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.flatten\niv flatten","url":"iv.html#flatten"},{"doc":"iv","title":"fold","content":"pub fn fold(\n  over array: Array(a),\n  from state: b,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; b\n Build up a new value by looping through each of the elements from the start\n to the end.\n\n \n fold(from_list([6, 7, 8]), from: 0, with: int.add)\n // --&gt; 21\n\n fold(from_list([6, 7, 8]), from: [], with: list.prepend)\n // --&gt; [8, 7, 6]\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.fold\niv fold","url":"iv.html#fold"},{"doc":"iv","title":"fold_right","content":"pub fn fold_right(\n  over array: Array(a),\n  from state: b,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; b\n Build up a new value by looping in reverse from the end to the start through\n the array.\n\n \n fold_right(from_list([6, 7, 8]), from: 0, with: int.add)\n // --&gt; 21\n\n fold_right(from_list([6, 7, 8]), from: [], with: list.prepend)\n // --&gt; [6, 7, 8]\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.fold_right\niv fold_right","url":"iv.html#fold_right"},{"doc":"iv","title":"from_list","content":"pub fn from_list(list: List(a)) -&gt; Array(a)\n Converts the given list to an array.\n\n \n length(from_list([1, 2, 3]))\n // --&gt; 3\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.from_list\niv from_list","url":"iv.html#from_list"},{"doc":"iv","title":"from_yielder","content":"pub fn from_yielder(source: Yielder(a)) -&gt; Array(a)\n Consume the given yielder, collecting all elements into a new array.\n\n \n from_yielder(\n   yielder.range(1, 3)\n   |&gt; yielder.cycle()\n   |&gt; yielder.take(10)\n )\n // --&gt; from_list([1, 2, 3, 1, 2, 3, 1, 2, 3, 1])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.from_yielder\niv from_yielder","url":"iv.html#from_yielder"},{"doc":"iv","title":"get","content":"pub fn get(from array: Array(a), at index: Int) -&gt; Result(a, Nil)\n Get the element at a specific index.\n\n Arrays are 0-based, so the first element is at index `0`, the second is at\n index `1`, the third is at index `2`, and so forth, up to `length - 1`.\n\n \n let array = from_list([&quot;trans&quot;, &quot;rights&quot;, &quot;are&quot;, &quot;human&quot;, &quot;rights&quot;])\n\n get(from: array, at: 1)\n // --&gt; Ok(&quot;rights&quot;)\n\n get(from: array, at: 3)\n // --&gt; Ok(&quot;human&quot;)\n\n get(from: array, at: -1)\n // --&gt; Error(Nil)\n\n get(from: array, at: 5)\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.get\niv get","url":"iv.html#get"},{"doc":"iv","title":"get_or_default","content":"pub fn get_or_default(\n  from array: Array(a),\n  at index: Int,\n  or default: a,\n) -&gt; a\n Get the element at a specific index, or a default value if the index is out\n of range.\n\n Arrays are 0-based, so the first element is at index `0`, the second is at\n index `1`, the third is at index `2`, and so forth, up to `length - 1`.\n\n \n let array = from_list([&quot;trans&quot;, &quot;rights&quot;, &quot;are&quot;, &quot;human&quot;, &quot;rights&quot;])\n\n get_or_default(from: array, at: 1, or: &quot;&quot;)\n // --&gt; &quot;rights&quot;\n\n get_or_default(from: array, at: 3, or: &quot;&quot;)\n // --&gt; &quot;human&quot;\n\n get_or_default(from: array, at: -1, or: &quot;&quot;)\n // --&gt; &quot;&quot;\n\n get_or_default(from: array, at: 5, or: &quot;&quot;)\n // --&gt; &quot;&quot;\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.get_or_default\niv get_or_default","url":"iv.html#get_or_default"},{"doc":"iv","title":"index_fold","content":"pub fn index_fold(\n  over array: Array(a),\n  from state: b,\n  with fun: fn(b, a, Int) -&gt; b,\n) -&gt; b\n Like `fold`, but also passes the index of the current element.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.index_fold\niv index_fold","url":"iv.html#index_fold"},{"doc":"iv","title":"index_map","content":"pub fn index_map(\n  array: Array(a),\n  with fun: fn(a, Int) -&gt; b,\n) -&gt; Array(b)\n Return a copy of the array, where each element is replaced by the result\n of applying a function to the index and the element at that index.\n\n \n index_map(from_list([6, 7, 8]), fn(x, i) { #(i, x) })\n // --&gt; from_list([#(0, 6), #(1, 7), #(2, 8)])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.index_map\niv index_map","url":"iv.html#index_map"},{"doc":"iv","title":"index_of","content":"pub fn index_of(\n  in array: Array(a),\n  of item: a,\n) -&gt; Result(Int, Nil)\n Return the index of the first occurrence of the given element in the array,\n or `Error(Nil)` if the array doesn&#39;t contain the element.\n\n \n index_of(from_list([4, 5, 6, 5]), of: 5)\n // --&gt; Ok(1)\n\n index_of(from_list([4, 5, 6, 5]), of: 1)\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.index_of\niv index_of","url":"iv.html#index_of"},{"doc":"iv","title":"initialise","content":"pub fn initialise(\n  length length: Int,\n  with fun: fn(Int) -&gt; a,\n) -&gt; Array(a)\n Create a list using a constructor function for each element.\n The function receives the current index as an input.\n\n \n initialise(5, fn(i) { i * 2 })\n // --&gt; from_list([0, 2, 4, 6, 8])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.initialise\niv initialise","url":"iv.html#initialise"},{"doc":"iv","title":"insert","content":"pub fn insert(\n  into array: Array(a),\n  at index: Int,\n  this item: a,\n) -&gt; Result(Array(a), Nil)\n Insert an element at an index into the array, moving all existing elements.\n\n This function runs in _O(log n)_ time.\n\n \n new() |&gt; insert(at: 0, this: &quot;hi&quot;)\n // --&gt; Ok(from_list([&quot;hi&quot;]))\n\n from_list([1, 2, 3]) |&gt; insert(at: 1, this: 50)\n // --&gt; Ok(from_list([1, 50, 2, 3]))\n\n from_list([1, 2, 3]) |&gt; insert(at: 3, this: 4)\n // --&gt; Ok(from_list([1, 2, 3, 4]))\n\n from_list([1, 2, 3]) |&gt; insert(at: 5, this: 100)\n // --&gt; Error(Nil)\n\n from_list([1, 2, 3]) |&gt; insert(at: -1, this: 0)\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.insert\niv insert","url":"iv.html#insert"},{"doc":"iv","title":"insert_clamped","content":"pub fn insert_clamped(\n  into array: Array(a),\n  at index: Int,\n  this item: a,\n) -&gt; Array(a)\n Insert an element at an index into the array, moving all existing elements.\n If the index is less than `0` prepend, and if it&#39;s greater than the number\n of elements in the array append instead.\n\n This function runs in _O(log n)_ time.\n\n \n new() |&gt; insert_clamped(at: 0, this: &quot;hi&quot;)\n // --&gt; from_list([&quot;hi&quot;])\n\n from_list([1, 2, 3]) |&gt; insert_clamped(at: 1, this: 50)\n // --&gt; from_list([1, 50, 2, 3])\n\n from_list([1, 2, 3]) |&gt; insert_clamped(at: 3, this: 4)\n // --&gt; from_list([1, 2, 3, 4])\n\n from_list([1, 2, 3]) |&gt; insert_clamped(at: 5, this: 100)\n // --&gt; from_list([1, 2, 3, 100])\n\n from_list([1, 2, 3]) |&gt; insert(at: -1, this: 0)\n // --&gt; from_list([0, 1, 2, 3])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.insert_clamped\niv insert_clamped","url":"iv.html#insert_clamped"},{"doc":"iv","title":"insert_list","content":"pub fn insert_list(\n  into array: Array(a),\n  at index: Int,\n  these items: List(a),\n) -&gt; Result(Array(a), Nil)\n Insert all elements in a given list to the array at a specific index,\n in the same order they appear in the list.\n\n This is more efficient than inserting all elements individually.\n\n This function runs in _O(n)_ time, only depending on the size of the inserted list.\n\n \n from_list([1, 2, 3]) |&gt; insert_list(at: 1, these: [34, 35])\n // --&gt; Ok(from_list([1, 34, 35, 2, 3]))\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.insert_list\niv insert_list","url":"iv.html#insert_list"},{"doc":"iv","title":"insert_list_clamped","content":"pub fn insert_list_clamped(\n  into array: Array(a),\n  at index: Int,\n  these items: List(a),\n) -&gt; Array(a)\n Insert elements at an index into the array, moving all existing elements.\n If the index is less than `0` prepend, and if it&#39;s greater than the number\n of elements in the array append instead.\n\n This is more efficient than inserting all elements individually.\n\n This function runs in _O(n)_ time, only depending on the size of the inserted list.\n\n \n from_list([1, 2, 3]) |&gt; insert_list_clamped(at: 1, these: [34, 35])\n // --&gt; from_list([1, 34, 35, 2, 3])\n\n from_list([1, 2, 3]) |&gt; insert_list_clamped(at: 100, these: [100, 101])\n // --&gt; from_list([1, 2, 3, 100, 101])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.insert_list_clamped\niv insert_list_clamped","url":"iv.html#insert_list_clamped"},{"doc":"iv","title":"is_empty","content":"pub fn is_empty(array: Array(a)) -&gt; Bool\n Check whether or not an array is empty.\n\n \n is_empty(from_list([]))\n  // --&gt; True\n\n is_empty(from_list([1, 2, 3]))\n // --&gt; False\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.is_empty\niv is_empty","url":"iv.html#is_empty"},{"doc":"iv","title":"last","content":"pub fn last(from array: Array(a)) -&gt; Result(a, Nil)\n Get the last element in the array, if there is one.\n\n \n last(new())\n // --&gt; Error(Nil)\n\n last(from_list([1]))\n // --&gt; Ok(1)\n\n last(from_list([1, 2, 3]))\n // --&gt; Ok(3)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.last\niv last","url":"iv.html#last"},{"doc":"iv","title":"last_index_of","content":"pub fn last_index_of(\n  in array: Array(a),\n  of item: a,\n) -&gt; Result(Int, Nil)\n Return the index of the last occurrence of the given element in the array,\n or `Error(Nil)` if the array doesn&#39;t contain the element.\n\n \n last_index_of(from_list([4, 5, 6, 5]), of: 5)\n // --&gt; Ok(3)\n\n last_index_of(from_list([4, 5, 6, 5]), of: 1)\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.last_index_of\niv last_index_of","url":"iv.html#last_index_of"},{"doc":"iv","title":"leading","content":"pub fn leading(array: Array(a)) -&gt; Result(Array(a), Nil)\n Return the array without the last element. If the array is empty,\n `Error(Nil)` is returned.\n\n \n leading(from_list([1, 2, 3]))\n // --&gt; Ok(from_list([1, 2]))\n\n leading(new())\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.leading\niv leading","url":"iv.html#leading"},{"doc":"iv","title":"length","content":"pub fn length(array: Array(a)) -&gt; Int\n Returns the number of items in the array.\n\n \n length(from_list([]))\n // --&gt; 0\n\n length(from_list([&quot;hello&quot;, &quot;joe&quot;]))\n // --&gt; 2\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.length\niv length","url":"iv.html#length"},{"doc":"iv","title":"map","content":"pub fn map(array: Array(a), with fun: fn(a) -&gt; b) -&gt; Array(b)\n Return a copy of the array, where each element is replaced by the result\n of a function.\n\n \n map(from_list([6, 7, 8]), fn(x) { x * 2 })\n // --&gt; from_list([12, 14, 16])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.map\niv map","url":"iv.html#map"},{"doc":"iv","title":"map2","content":"pub fn map2(\n  a: Array(a),\n  b: Array(b),\n  with fun: fn(a, b) -&gt; c,\n) -&gt; Array(c)\n Combine 2 arrays into a single array using the given function.\n\n If one array is longer than the other, the extra elements are dropped from\n the end.\n\n \n map2(from_list([1, 2, 3]), from_list([4, 5, 6]), int.add)\n // --&gt; from_list([5, 7, 9])\n\n map2(from_list([1, 2]), from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]), fn(a, b) { #(a, b) })\n // --&gt; from_list([#(1, &quot;a&quot;), #(2, &quot;b&quot;)])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.map2\niv map2","url":"iv.html#map2"},{"doc":"iv","title":"new","content":"pub fn new() -&gt; Array(a)\n Returns a new empty array.\n\n \n new()\n // --&gt; from_list([])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.new\niv new","url":"iv.html#new"},{"doc":"iv","title":"prepend","content":"pub fn prepend(to array: Array(a), this item: a) -&gt; Array(a)\n Add an element to the start of the array, making it the first element.\n\n This function runs in _O(log n)_ time.\n\n \n from_list([&quot;joe&quot;]) |&gt; prepend(&quot;hello&quot;)\n // --&gt; from_list([&quot;hello&quot;, &quot;joe&quot;])\n\n from_list([1, 2, 3]) |&gt; prepend(4) |&gt; prepend(0)\n // --&gt; from_list([0, 4, 1, 2, 3])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.prepend\niv prepend","url":"iv.html#prepend"},{"doc":"iv","title":"prepend_list","content":"pub fn prepend_list(\n  to array: Array(a),\n  these items: List(a),\n) -&gt; Array(a)\n Add many elements to the start of the array, in the same order they appear\n in the list.\n\n This is more efficient than inserting all elements individually.\n\n This function runs in _O(n)_ time, only depending on the size of the prepended list.\n\n \n from_list([1, 2, 3]) |&gt; prepend_list([4, 5, 6])\n // --&gt; from_list([4, 5, 6, 1, 2, 3])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.prepend_list\niv prepend_list","url":"iv.html#prepend_list"},{"doc":"iv","title":"range","content":"pub fn range(from start: Int, to stop: Int) -&gt; Array(Int)\n Creates a list of ints ranging from a given start and finish.\n\n \n range(1, 3)\n // --&gt; from_list([1, 2, 3])\n\n range(10, 1)\n // --&gt; from_list([10, 9, 8, 7, 6, 5, 4, 3, 2, 1])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.range\niv range","url":"iv.html#range"},{"doc":"iv","title":"repeat","content":"pub fn repeat(item item: a, times times: Int) -&gt; Array(a)\n Build an array by repeating the given element a number of times.\n\n \n repeat(&quot;hi&quot;, times: 3)\n // --&gt; from_list([&quot;hi&quot;, &quot;hi&quot;, &quot;hi&quot;])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.repeat\niv repeat","url":"iv.html#repeat"},{"doc":"iv","title":"replace","content":"pub fn replace(\n  from array: Array(a),\n  at index: Int,\n  replace count: Int,\n  with replacements: Array(a),\n) -&gt; Result(Array(a), Nil)\n Replace a slice with a different array.\n\n The entire slice has to exist in the array. Otherwise, `Error(Nil)` is returned.\n\n This function runs in _O(log n)_ time.\n\n \n from_list([1, 2, 3, 4]) |&gt; replace(at: 1, replace: 2, with: from_list([7, 8, 9]))\n // --&gt; Ok(from_list([1, 7, 8, 9, 4]))\n\n from_list([1, 2, 3]) |&gt; replace(at: 2, replace: 1, with: from_list([7, 8, 9]))\n // --&gt; Ok(from_list([1, 2, 7, 8, 9]))\n\n from_list([1, 2, 3]) |&gt; replace(at: 2, replace: 2, with: from_list([8, 8, 9]))\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.replace\niv replace","url":"iv.html#replace"},{"doc":"iv","title":"rest","content":"pub fn rest(array: Array(a)) -&gt; Result(Array(a), Nil)\n Return the array without the first element. If the array is empty,\n `Error(Nil)` is returned.\n\n \n rest(from_list([1, 2, 3]))\n // --&gt; Ok(from_list([2, 3]))\n\n rest(new())\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.rest\niv rest","url":"iv.html#rest"},{"doc":"iv","title":"reverse","content":"pub fn reverse(array: Array(a)) -&gt; Array(a)\n Create a new array containing the same elements, but in the opposite order.\n\n \n reverse(from_list([6, 7, 8]))\n // --&gt; from_list([8, 7, 6])\n\n reverse(from_list([1]))\n // --&gt; from_list([1])\n\n reverse(new())\n // --&gt; new()\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.reverse\niv reverse","url":"iv.html#reverse"},{"doc":"iv","title":"set","content":"pub fn set(\n  in array: Array(a),\n  at index: Int,\n  to item: a,\n) -&gt; Result(Array(a), Nil)\n Store a new value at a given index and return the new array, or `Error(Nil)`\n if the index cannot be found in the array.\n\n \n from_list([1, 2, 3]) |&gt; set(at: 1, to: 50)\n // --&gt; Ok(from_list([1, 50, 3]))\n\n from_list([1, 2, 3]) |&gt; set(at: -1, to: 50)\n // --&gt; Error(Nil)\n\n from_list([]) |&gt; set(at: 0, to: 1)\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.set\niv set","url":"iv.html#set"},{"doc":"iv","title":"slice","content":"pub fn slice(\n  from array: Array(a),\n  start start: Int,\n  size size: Int,\n) -&gt; Result(Array(a), Nil)\n Extract a sub-slice from the array. If the start is not part of the\n array or if the array does not contain enough elements, `Error(Nil)` is returned.\n\n This function runs in _O(log n)_ time.\n\n \n let array = from_list([6, 7, 8, 9])\n\n slice(from: array, start: 1, size: 2)\n // --&gt; Ok(from_list([7, 8]))\n\n slice(from: array, start: 2, size: 3)\n // --&gt; Error(Nil)\n\n slice(from: array, start: 5, size: 0)\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.slice\niv slice","url":"iv.html#slice"},{"doc":"iv","title":"splice","content":"pub fn splice(\n  from array: Array(a),\n  at index: Int,\n  replace count: Int,\n  with replacer: fn(Array(a)) -&gt; Array(a),\n) -&gt; Result(Array(a), Nil)\n Replace a slice using a function, returning the new elements.\n\n The entire slice has to exist in the array. Otherwise, `Error(Nil)` is returned.\n\n This function runs in _O(log n)_ time.\n\n \n from_list([1, 2, 3, 4]) |&gt; splice(at: 1, replace: 2, with: fn(slice) {\n   map(slice, fn(x) { x * 2 })\n })\n // --&gt; Ok(from_list([1, 4, 6, 4]))\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.splice\niv splice","url":"iv.html#splice"},{"doc":"iv","title":"split","content":"pub fn split(\n  array: Array(a),\n  at index: Int,\n) -&gt; #(Array(a), Array(a))\n Split an array in two before the given index.\n\n If the list is not long enough to have the given index the before list will\n be the input list, and the after list will be empty.\n\n \n split(from_list([6, 7, 8, 9]), at: 0)\n // --&gt; #(new(), from_list([6, 7, 8, 9]))\n\n split(from_list([6, 7, 8, 9]), at: 2)\n // --&gt; #(from_list([6, 7]), from_list([8, 9]))\n\n split(from_list([6, 7, 8, 9]), at: 4)\n // --&gt; #(from_list([6, 7, 8, 9]), new())\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.split\niv split","url":"iv.html#split"},{"doc":"iv","title":"take_first","content":"pub fn take_first(from array: Array(a), up_to n: Int) -&gt; Array(a)\n Return up to the first `n` elements from the start of the array.\n\n If the array has less than `n` elements, the original array is returned.\n\n This function runs in _O(log n)_ time.\n\n \n take_first(from_list([6, 7, 8, 9]), up_to: 3)\n // --&gt; from_list([6, 7, 8])\n\n take_first(from_list([6, 7, 8, 9]), up_to: 10)\n // --&gt; from_list([6, 7, 8, 9])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.take_first\niv take_first","url":"iv.html#take_first"},{"doc":"iv","title":"take_last","content":"pub fn take_last(from array: Array(a), up_to n: Int) -&gt; Array(a)\n Return up `n` elements from the end of the array.\n\n If the array has less than `n` elements, the original array is returned.\n\n This function runs in _O(log n)_ time.\n\n \n take_last(from_list([6, 7, 8, 9]), up_to: 3)\n // --&gt; from_list([7, 8, 9])\n\n take_last(from_list([6, 7, 8, 9]), up_to: 10)\n // --&gt; from_list([6, 7, 8, 9])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.take_last\niv take_last","url":"iv.html#take_last"},{"doc":"iv","title":"to_list","content":"pub fn to_list(array: Array(a)) -&gt; List(a)\n Convert an array to a standard Gleam list.\n\n \n to_list(range(1, 5))\n // --&gt; [1, 2, 3, 4, 5]\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.to_list\niv to_list","url":"iv.html#to_list"},{"doc":"iv","title":"to_yielder","content":"pub fn to_yielder(array: Array(a)) -&gt; Yielder(a)\n Return a yielder iterating through an array.\n\n Yielders are more efficient then repeatetly querying the index, but slower\n than using more specialised functions like [each](#each) or [fold](#fold).\n Only use this if you need to pause or iterate through many arrays at once.\n\n \n to_yielder(from_list([1, 2, 3]))\n |&gt; yielder.cycle\n |&gt; yielder.take(10)\n |&gt; yielder.to_list\n // --&gt; [1, 2, 3, 1, 2, 3, 1, 2, 3, 1]\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.to_yielder\niv to_yielder","url":"iv.html#to_yielder"},{"doc":"iv","title":"try_delete","content":"pub fn try_delete(\n  from array: Array(a),\n  at index: Int,\n) -&gt; Array(a)\n Remove the element at a given index, moving all subsequent elements\n to the left. If the index does not exist, return the array unchanged.\n\n This function runs in _O(log n)_ time.\n\n \n from_list([1, 2, 3]) |&gt; try_delete(at: 1)\n // --&gt; from_list([1, 3])\n\n from_list([1, 2, 3]) |&gt; try_delete(at: 3)\n // --&gt; from_list([1, 2, 3])\n\n from_list([]) |&gt; try_delete(at: 0)\n // --&gt; from_list([])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.try_delete\niv try_delete","url":"iv.html#try_delete"},{"doc":"iv","title":"try_each","content":"pub fn try_each(\n  in array: Array(a),\n  do something: fn(a) -&gt; Result(b, c),\n) -&gt; Result(Nil, c)\n Loop through the elements from the start to the end, calling a\n result-returning function for all of them. As soon as the function returns\n `Error(_)`, iteration is stopped and the error is returned.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.try_each\niv try_each","url":"iv.html#try_each"},{"doc":"iv","title":"try_fold","content":"pub fn try_fold(\n  over array: Array(a),\n  from state: b,\n  with fun: fn(b, a) -&gt; Result(b, c),\n) -&gt; Result(b, c)\n A variant of `fold` that builds up a new value using a function that can\n fail.\n\n If the function returns `Error(_)`, iteration is stopped and the error is\n returned immediately. Otherwise, the final built-up value is returned.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.try_fold\niv try_fold","url":"iv.html#try_fold"},{"doc":"iv","title":"try_map","content":"pub fn try_map(\n  over array: Array(a),\n  with fun: fn(a) -&gt; Result(b, c),\n) -&gt; Result(Array(b), c)\n Return a copy of the array, where each element is replaced by the `Ok(_)`\n result of applying a function to each element.\n\n If the fuction returns `Error(_)` for any of the elements, that error is\n immediately returned instead.\n\n \n try_map(from_list([[1], [2, 3]]), list.first)\n // --&gt; Ok(from_list([1, 2]))\n\n try_map(from_list([[1], [], [2, 3]]), list.first)\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.try_map\niv try_map","url":"iv.html#try_map"},{"doc":"iv","title":"try_set","content":"pub fn try_set(\n  in array: Array(a),\n  at index: Int,\n  to item: a,\n) -&gt; Array(a)\n Store a new value at a given index and return the new array, or return the\n given array unchanged if the index cannot be found.\n\n \n from_list([1, 2, 3]) |&gt; try_set(at: 1, to: 50)\n // --&gt; from_list([1, 50, 3])\n\n from_list([1, 2, 3]) |&gt; try_set(at: -1, to: 50)\n // --&gt; from_list([1, 2, 3])\n\n from_list([]) |&gt; try_set(at: 0, to: 1)\n // --&gt; from_list([])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.try_set\niv try_set","url":"iv.html#try_set"},{"doc":"iv","title":"try_update","content":"pub fn try_update(\n  in array: Array(a),\n  at index: Int,\n  with fun: fn(a) -&gt; a,\n) -&gt; Array(a)\n Update the element at a given index and return a new array, or return the\n given array unchanged if the index cannot be found in the array.\n\n This is more efficient than `get`-ing and then `try_set`-ing the element.\n\n \n from_list([1, 2, 3]) |&gt; try_update(at: 1, with: fn(x) { x * 2 })\n // --&gt; from_list([1, 4, 3])\n\n from_list([1, 2, 3]) |&gt; try_update(at: -1, with: fn(x) { x + 1 })\n // --&gt; from_list([1, 2, 3])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.try_update\niv try_update","url":"iv.html#try_update"},{"doc":"iv","title":"update","content":"pub fn update(\n  in array: Array(a),\n  at index: Int,\n  with fun: fn(a) -&gt; a,\n) -&gt; Result(Array(a), Nil)\n Update the element at a given index and return a new array, or return\n `Error(Nil)` if the index cannot be found in the array.\n\n This is slightly more efficient than `get`-ing and then `set`-ing the element.\n\n \n from_list([1, 2, 3]) |&gt; update(at: 1, with: fn(x) { x * 2 })\n // --&gt; Ok(from_list([1, 4, 3]))\n\n from_list([1, 2, 3]) |&gt; update(at: -1, with: fn(x) { x + 1 })\n // --&gt; Error(Nil)\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.update\niv update","url":"iv.html#update"},{"doc":"iv","title":"wrap","content":"pub fn wrap(of item: a) -&gt; Array(a)\n Returns the given item wrapped in a list.\n\n \n wrap(42)\n // --&gt; from_list([42])\n\n wrap(from_list([1, 2, 3]))\n // --&gt; from_list([from_list([1, 2, 3])])\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.wrap\niv wrap","url":"iv.html#wrap"},{"doc":"iv","title":"zip","content":"pub fn zip(a: Array(a), b: Array(b)) -&gt; Array(#(a, b))\n Combine 2 arrays into a single array of 2-element tuples.\n\n If one array is longer than the other, the extra elements are dropped from\n the end.\n\n \n zip(from_list([1, 2, 3]), from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]))\n // --&gt; from_list([#(1, &quot;a&quot;), #(2, &quot;b&quot;), #(3, &quot;c&quot;)])\n\n zip(from_list([]), from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]))\n // --&gt; new()\n \n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\niv.zip\niv zip","url":"iv.html#zip"},{"doc":"iv","title":"iv","content":" &lt;style&gt;\n   small {\n     font-size: 0.7em;\n     opacity: 0.75;\n   }\n   h4 {\n     margin-bottom: 0;\n     + p {\n       margin-top: 0;\n     }\n   }\n &lt;/style&gt;\n\n `iv` is an immutable array structure written in Gleam. You can use it\n like you would use an array in other programming languages and expect\n comparable or better runtime characteristics.\n\n **Tip:** Hover the links for short summaries!\n\n #### Create &amp; Convert\n [new](#new &quot;Create an empty array&quot;),\n [wrap](#wrap &quot;A single element&quot;),\n [repeat](#repeat &quot;Repeat a single element&quot;),\n [range](#range &quot;Range of integers&quot;),\n [from_list](#from_list &quot;Convert a list to an array&quot;),\n [from_yielder](#from_yielder &quot;Consume any yielder to build an array&quot;),\n [initialise](#initialise &quot;Use a constructor function for every element&quot;) \\\n [to_list](#to_list &quot;Convert to a list&quot;),\n [to_yielder](#to_yielder &quot;Create a yielder iterating through the array&quot;)\n\n #### Query\n [is_empty](#is_empty &quot;Is the array empty?&quot;),\n [length](#length &quot;Number of elements&quot;),\n [equal](#equal &quot;Are 2 arrays equal?&quot;),\n [any](#any &quot;Does any element have a property?&quot;),\n [all](#all &quot;Do all elements have a property?&quot;) \\\n [contains](#contains &quot;Does the array contain an element?&quot;),\n [index_of](#index_of &quot;Get the index of an element&quot;),\n [last_index_of](#last_index_of &quot;Get index of an element from the end&quot;),\n [get](#get &quot;Get the element at an index&quot;),\n [get_or_default](#get_or_default &quot;Get the element at an index or a fallback value&quot;),\n [first](#first &quot;Get the first element&quot;),\n [last](#last &quot;Get the last element&quot;),\n [find](#find &quot;Find the first element with a property&quot;),\n [find_index](#find_index &quot;Find the index of the first element with a property&quot;),\n [find_last](#find_last &quot;Find the last element with a property&quot;),\n [find_last_index](#find_last_index &quot;Find the index of the last element with a property&quot;),\n [find_map](#find_map &quot;Find the first Ok(_)&quot;)\n\n #### Manipulate\n\n [set](#set &quot;Set an element&quot;),\n [try_set](#try_set &quot;Set an element if the index exists&quot;),\n [update](#update &quot;Update an element&quot;),\n [try_update](#try_update &quot;Update an element if the index exists&quot;)\n [insert](#insert &quot;Insert an element&quot;),\n [insert_clamped](#insert_clamped &quot;Insert, prepend, or append an element&quot;),\n [insert_list](#insert_list &quot;Insert many elements&quot;),\n [insert_list_clamped](#insert_list_clamped, &quot;Insert, prepend, or append many elements&quot;),\n [delete](#delete &quot;Delete an element&quot;),\n [try_delete](#try_delete &quot;Delete an element, if it exists&quot;) \\\n [append](#append &quot;Add an element to the end&quot;),\n [append_list](#append_list &quot;Add many elements to the end&quot;),\n [prepend](#prepend &quot;Add an element at the start&quot;),\n [prepend_list](#prepend_list &quot;Add many elements at the start&quot;),\n [replace](#replace &quot;Replace a range of elements&quot;),\n [splice](#splice &quot;Replace a range of elements using a function&quot;)\n\n #### Concatenate &amp; Split\n [concat](#concat &quot;Concatenate two arrays&quot;),\n [concat_list](#concat_list &quot;Concatenate many arrays&quot;),\n [flatten](#flatten &quot;Concatenate nested arrays&quot;),\n [split](#split &quot;Split an array at an index&quot;),\n [slice](#slice &quot;Get a slice of the array&quot;),\n [drop_first](#drop_first &quot;Remove the first elements&quot;),\n [drop_last](#drop_last &quot;Remove the last elements&quot;),\n [take_first](#take_first &quot;Take the first elements&quot;),\n [take_last](#take_last &quot;Take the last elements&quot;),\n [leading](#leading &quot;Get all but the last element&quot;),\n [rest](#rest &quot;Get all but the first element&quot;)\n\n #### Transform\n [reverse](#reverse &quot;Reverse the order&quot;),\n [map](#map &quot;Transform every element&quot;),\n [try_map](#try_map &quot;Transform every element using a fallible function&quot;),\n [index_map](#index_map &quot;Transform every element using its index&quot;),\n [flat_map](#flat_map &quot;Map every element to anoher array&quot;),\n [filter](#filter &quot;Filter elements based on a property&quot;),\n [filter_map](#filter_map &quot;Collect all Ok values&quot;),\n [zip](#zip &quot;Combine elements of 2 arrays&quot;),\n [map2](#map2 &quot;Combine 2 arrays usng a function&quot;)\n\n #### Looping\n [each](#each &quot;Loop start to end&quot;),\n [try_each](#try_each &quot;Loop until error&quot;),\n [each_right](#each_right &quot;Loop end to start&quot;),\n [fold](#fold &quot;Loop start to end, with state&quot;),\n [index_fold](#index_fold &quot;Loop with the index, start to end&quot;),\n [try_fold](#try_fold &quot;Loop until error, with state&quot;),\n [fold_right](#fold_right &quot;Loop end to start, with state&quot;)","url":"iv.html"}]);